@@ -508,6 +508,7 @@ env "local" {
 				Tenant string
 				cmdlog.MigrateApply
 			}
+			fmt.Println(s)
 			require.NoError(t, json.Unmarshal([]byte(s), &r))
 			require.Empty(t, r.Pending)
 			require.Empty(t, r.Applied)
@@ -863,6 +864,63 @@ func TestMigrate_Diff(t *testing.T) {
 		require.NoError(t, err)
 		require.Len(t, files, 2)
 	})
+
+	t.Run("Format", func(t *testing.T) {
+		for f, out := range map[string]string{
+			"{{sql .}}":            "CREATE TABLE `t` (`c` int NULL);",
+			`{{- sql . "  " -}}`:   "CREATE TABLE `t` (\n  `c` int NULL\n);",
+			"{{ sql . \"\t\" }}":   "CREATE TABLE `t` (\n\t`c` int NULL\n);",
+			"{{sql $ \"  \t  \"}}": "CREATE TABLE `t` (\n  \t  `c` int NULL\n);",
+		} {
+			p := t.TempDir()
+			d, err := migrate.NewLocalDir(p)
+			require.NoError(t, err)
+			// Works with indentation.
+			s, err = runCmd(
+				migrateDiffCmd(),
+				"name",
+				"--dir", "file://"+p,
+				"--dev-url", openSQLite(t, ""),
+				"--to", openSQLite(t, "create table t (c int);"),
+				"--format", f,
+			)
+			require.NoError(t, err)
+			require.Zero(t, s)
+			files, err := d.Files()
+			require.NoError(t, err)
+			require.Len(t, files, 1)
+			require.Equal(t, "-- Create \"t\" table\n"+out+"\n", string(files[0].Bytes()))
+		}
+
+		// Invalid use of sql.
+		s, err = runCmd(
+			migrateDiffCmd(),
+			"name",
+			"--dir", "file://"+p,
+			"--dev-url", openSQLite(t, ""),
+			"--to", openSQLite(t, "create table t (c int);"),
+			"--format", `{{ if . }}{{ sql . "  " }}{{ end }}`,
+		)
+		require.EqualError(t, err, `'sql' can only be used to indent statements. got: {{if .}}{{sql . "  "}}{{end}}`)
+
+		// Valid template.
+		p := t.TempDir()
+		d, err := migrate.NewLocalDir(p)
+		require.NoError(t, err)
+		s, err = runCmd(
+			migrateDiffCmd(),
+			"name",
+			"--dir", "file://"+p,
+			"--dev-url", openSQLite(t, ""),
+			"--to", openSQLite(t, "create table t (c int);"),
+			"--format", `{{ range .Changes }}{{ .Cmd }}{{ end }}`,
+		)
+		require.NoError(t, err)
+		files, err := d.Files()
+		require.NoError(t, err)
+		require.Len(t, files, 1)
+		require.Equal(t, "CREATE TABLE `t` (`c` int NULL)", string(files[0].Bytes()))
+	})
 }
 
 func TestMigrate_StatusJSON(t *testing.T) {
@@ -871,7 +929,7 @@ func TestMigrate_StatusJSON(t *testing.T) {
 		migrateStatusCmd(),
 		"--dir", "file://"+p,
 		"-u", openSQLite(t, ""),
-		"--log", "{{ json .Env.Driver }}",
+		"--format", "{{ json .Env.Driver }}",
 	)
 	require.NoError(t, err)
 	require.Equal(t, `"sqlite3"`, s)
@@ -1138,7 +1196,7 @@ func TestMigrate_Lint(t *testing.T) {
 		"--dir", "file://"+p,
 		"--dev-url", openSQLite(t, ""),
 		"--latest", "1",
-		"--log", "{{ range .Files }}{{ .Name }}{{ end }}",
+		"--log", "{{ range .Files }}{{ .Name }}{{ end }}", // Backward compatibility with old flag name.
 	)
 	require.Error(t, err)
 	require.Equal(t, "2.sql", s)
@@ -1151,7 +1209,7 @@ func TestMigrate_Lint(t *testing.T) {
 		"--dir", "file://"+p+"?format="+formatGolangMigrate,
 		"--dev-url", openSQLite(t, ""),
 		"--latest", "2",
-		"--log", "{{ range .Files }}{{ .Name }}:{{ len .Reports }}{{ end }}",
+		"--format", "{{ range .Files }}{{ .Name }}:{{ len .Reports }}{{ end }}",
 	)
 	require.NoError(t, err)
 	require.Equal(t, "1.up.sql:0", s)
@@ -1160,7 +1218,7 @@ func TestMigrate_Lint(t *testing.T) {
 		"--dir", "file://"+p+"?format="+formatGolangMigrate,
 		"--dev-url", openSQLite(t, ""),
 		"--latest", "2",
-		"--log", "{{ range .Files }}{{ .Name }}:{{ len .Reports }}{{ end }}",
+		"--format", "{{ range .Files }}{{ .Name }}:{{ len .Reports }}{{ end }}",
 		"--dir-format", formatGolangMigrate,
 	)
 	require.NoError(t, err)
