@@ -6,13 +6,18 @@ package cmdext_test
 
 import (
 	"context"
+	"encoding/base64"
+	"encoding/json"
 	"fmt"
+	"net/http"
+	"net/http/httptest"
 	"net/url"
 	"os"
 	"path/filepath"
 	"strings"
 	"testing"
 
+	"ariga.io/atlas/cmd/atlas/internal/cloudapi"
 	"ariga.io/atlas/cmd/atlas/internal/cmdext"
 	"ariga.io/atlas/schemahcl"
 	"ariga.io/atlas/sql/migrate"
@@ -128,15 +133,18 @@ func TestEntLoader_MigrateDiff(t *testing.T) {
 		dir, err := migrate.NewLocalDir(t.TempDir())
 		require.NoError(t, err)
 		err = d.MigrateDiff(ctx, &cmdext.MigrateDiffOptions{
-			Name: "boring",
-			Dev:  drv,
-			Dir:  dir,
-			To:   []string{"ent://../migrate/ent/schema?globalid=1"},
+			Name:   "boring",
+			Indent: "\t",
+			Dev:    drv,
+			Dir:    dir,
+			To:     []string{"ent://../migrate/ent/schema?globalid=1"},
 		})
 		require.NoError(t, err)
 		files, err := dir.Files()
 		require.NoError(t, err)
 		require.True(t, strings.HasSuffix(files[0].Name(), "_boring.sql"))
+		// Statements were generated with indentation.
+		require.Contains(t, string(files[0].Bytes()), "CREATE TABLE `atlas_schema_revisions` (\n\t")
 	})
 
 	t.Run("OtherFormat", func(t *testing.T) {
@@ -196,3 +204,117 @@ dir = data.template_dir.tenant.url
 	require.Equal(t, "1.sql", files[0].Name())
 	require.Equal(t, "create table a8m.t(c int);", string(files[0].Bytes()))
 }
+
+func TestAtlasConfig(t *testing.T) {
+	var (
+		v struct {
+			Env       string   `spec:"env"`
+			HasClient bool     `spec:"has_client"`
+			CloudKeys []string `spec:"cloud_keys"`
+		}
+		state = schemahcl.New(append(cmdext.DataSources, schemahcl.WithVariables(map[string]cty.Value{
+			"atlas": cty.ObjectVal(map[string]cty.Value{
+				"env": cty.StringVal("dev"),
+			}),
+		}))...)
+	)
+	err := state.EvalBytes([]byte(`
+atlas {
+  cloud {
+    url = "url"
+    token = "token"
+  }
+}
+
+env = atlas.env
+has_client = atlas.cloud != null
+cloud_keys = keys(atlas.cloud)
+`), &v, map[string]cty.Value{})
+	require.NoError(t, err)
+	require.Equal(t, "dev", v.Env)
+	require.True(t, v.HasClient)
+	require.Equal(t, []string{"client"}, v.CloudKeys, "token and url should not be exported")
+}
+
+func TestRemoteDir(t *testing.T) {
+	var (
+		v struct {
+			Dir string `spec:"dir"`
+		}
+		token string
+		tag   string
+		state = schemahcl.New(cmdext.DataSources...)
+		srv   = httptest.NewServer(http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
+			token = r.Header.Get("Authorization")
+			di := struct {
+				Variables struct {
+					DirInput cloudapi.DirInput `json:"input"`
+				} `json:"variables"`
+			}{}
+			err := json.NewDecoder(r.Body).Decode(&di)
+			require.NoError(t, err)
+			tag = di.Variables.DirInput.Tag
+			d := migrate.MemDir{}
+			if err := d.WriteFile("1.sql", []byte("create table t(c int);")); err != nil {
+				http.Error(w, err.Error(), http.StatusInternalServerError)
+			}
+			sum, err := d.Checksum()
+			if err != nil {
+				http.Error(w, err.Error(), http.StatusInternalServerError)
+			}
+			if err := migrate.WriteSumFile(&d, sum); err != nil {
+				http.Error(w, err.Error(), http.StatusInternalServerError)
+			}
+			arch, err := migrate.ArchiveDir(&d)
+			if err != nil {
+				http.Error(w, err.Error(), http.StatusInternalServerError)
+			}
+			fmt.Fprintf(w, `{"data":{"dir":{"content":%q}}}`, base64.StdEncoding.EncodeToString(arch))
+		}))
+	)
+	defer srv.Close()
+
+	err := state.EvalBytes([]byte(`
+data "remote_dir" "hello" {
+  name  = "atlas"
+}
+`), &v, map[string]cty.Value{"cloud_url": cty.StringVal(srv.URL)})
+	require.EqualError(t, err, "data.remote_dir.hello: missing atlas cloud config")
+
+	err = state.EvalBytes([]byte(`
+variable "cloud_url" {
+  type = string
+}
+
+variable "tag" {
+  type = string
+}
+
+atlas {
+  cloud {
+    token = "token"
+    url = var.cloud_url
+  }
+}
+
+data "remote_dir" "hello" {
+  name  = "atlas"
+  tag = var.tag
+}
+
+dir = data.remote_dir.hello.url
+`), &v, map[string]cty.Value{"cloud_url": cty.StringVal(srv.URL), "tag": cty.StringVal("xyz")})
+	require.NoError(t, err)
+	require.Equal(t, "Bearer token", token)
+	require.Equal(t, "xyz", tag)
+	md := migrate.OpenMemDir(strings.TrimPrefix(v.Dir, "mem://"))
+	defer md.Close()
+	files, err := md.Files()
+	require.NoError(t, err)
+	require.Len(t, files, 1)
+	require.Equal(t, "1.sql", files[0].Name())
+	require.Equal(t, "create table t(c int);", string(files[0].Bytes()))
+	require.NoError(t, migrate.Validate(md))
+	_, err = md.Open(migrate.HashFileName)
+	require.NoError(t, err)
+}
