@@ -83,19 +83,24 @@ func (d *diff) defaultChanged(from, to *schema.Column) (bool, error) {
 	if ok1 != ok2 {
 		return true, nil
 	}
-	if trimCast(d1) == trimCast(d2) || quote(d1) == quote(d2) {
+	if !ok1 && !ok2 || trimCast(d1) == trimCast(d2) || quote(d1) == quote(d2) {
 		return false, nil
 	}
 	var (
-		err    error
-		equals bool
+		_, fromX = from.Default.(*schema.RawExpr)
+		_, toX   = to.Default.(*schema.RawExpr)
 	)
-	// In case a database connection is available (not the DefaultDiff), we use the
-	// database comparison in case of mismatch (e.g. `SELECT ARRAY[1] = '{1}'::int[]`).
-	if d.conn.ExecQuerier != nil {
-		equals, err = d.valuesEqual(d1, d2)
+	// In case one of the DEFAULT values is an expression, and a database connection is
+	// available (not DefaultDiff), we use the database to compare in case of mismatch.
+	//
+	//	SELECT ARRAY[1] = '{1}'::int[]
+	//	SELECT lower('X'::text) = lower('X')
+	//
+	if (fromX || toX) && d.conn.ExecQuerier != nil {
+		equals, err := d.defaultEqual(from.Default, to.Default)
+		return !equals, err
 	}
-	return !equals, err
+	return true, nil
 }
 
 // generatedChanged reports if the generated expression of a column was changed.
@@ -231,8 +236,8 @@ func (d *diff) typeChanged(from, to *schema.Column) (bool, error) {
 	}
 	var changed bool
 	switch fromT := fromT.(type) {
-	case *schema.BinaryType, *BitType, *schema.BoolType, *schema.DecimalType, *schema.FloatType,
-		*IntervalType, *schema.IntegerType, *schema.JSONType, *RangeType, *SerialType, *schema.SpatialType,
+	case *schema.BinaryType, *BitType, *schema.BoolType, *schema.DecimalType, *schema.FloatType, *IntervalType,
+		*schema.IntegerType, *schema.JSONType, *OIDType, *RangeType, *SerialType, *schema.SpatialType,
 		*schema.StringType, *schema.TimeType, *TextSearchType, *NetworkType, *UserDefinedType, *schema.UUIDType:
 		t1, err := FormatType(toT)
 		if err != nil {
@@ -285,13 +290,28 @@ func (d *diff) typeChanged(from, to *schema.Column) (bool, error) {
 	return changed, nil
 }
 
-// valuesEqual reports if the DEFAULT values x and y
+// defaultEqual reports if the DEFAULT values x and y
 // equal according to the database engine.
-func (d *diff) valuesEqual(x, y string) (bool, error) {
-	var b bool
+func (d *diff) defaultEqual(from, to schema.Expr) (bool, error) {
+	var (
+		b      bool
+		d1, d2 string
+	)
+	switch from := from.(type) {
+	case *schema.Literal:
+		d1 = quote(from.V)
+	case *schema.RawExpr:
+		d1 = from.X
+	}
+	switch to := to.(type) {
+	case *schema.Literal:
+		d2 = quote(to.V)
+	case *schema.RawExpr:
+		d2 = to.X
+	}
 	// The DEFAULT expressions are safe to be inlined in the SELECT
 	// statement same as we inline them in the CREATE TABLE statement.
-	rows, err := d.QueryContext(context.Background(), fmt.Sprintf("SELECT %s = %s", x, y))
+	rows, err := d.QueryContext(context.Background(), fmt.Sprintf("SELECT %s = %s", d1, d2))
 	if err != nil {
 		return false, err
 	}
